<?php

namespace Litecms\BookingManagement\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\BookingManagement\Http\Requests\BookingManagementRequest;
use Litecms\BookingManagement\Models\BookingManagement;

/**
 * Admin web controller class.
 */
class BookingManagementWorkflowController extends BaseController
{

    /**
     * Workflow controller function for booking_management.
     *
     * @param Model   $booking_management
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(BookingManagementRequest $request, BookingManagement $booking_management, $step)
    {

        try {

            $booking_management->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('booking_management::booking_management.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/booking_management/booking_management/' . $booking_management->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/booking_management/booking_management/' . $booking_management->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for booking_management.
     *
     * @param Model   $booking_management
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(BookingManagement $booking_management, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $booking_management->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('booking_management::booking_management.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('booking_management::admin.booking_management.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('booking_management::admin.booking_management.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('booking_management::admin.booking_management.message', $data)->render();

        }

    }
}
