<?php

namespace Litecms\BookingManagement\Workflow;

use Litecms\BookingManagement\Models\BookingManagement;
use Validator;

class BookingManagementValidator
{

    /**
     * Determine if the given booking_management is valid for complete status.
     *
     * @param BookingManagement $booking_management
     *
     * @return bool / Validator
     */
    public function complete(BookingManagement $booking_management)
    {
        return Validator::make($booking_management->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given booking_management is valid for verify status.
     *
     * @param BookingManagement $booking_management
     *
     * @return bool / Validator
     */
    public function verify(BookingManagement $booking_management)
    {
        return Validator::make($booking_management->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given booking_management is valid for approve status.
     *
     * @param BookingManagement $booking_management
     *
     * @return bool / Validator
     */
    public function approve(BookingManagement $booking_management)
    {
        return Validator::make($booking_management->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given booking_management is valid for publish status.
     *
     * @param BookingManagement $booking_management
     *
     * @return bool / Validator
     */
    public function publish(BookingManagement $booking_management)
    {
        return Validator::make($booking_management->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given booking_management is valid for archive status.
     *
     * @param BookingManagement $booking_management
     *
     * @return bool / Validator
     */
    public function archive(BookingManagement $booking_management)
    {
        return Validator::make($booking_management->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given booking_management is valid for unpublish status.
     *
     * @param BookingManagement $booking_management
     *
     * @return bool / Validator
     */
    public function unpublish(BookingManagement $booking_management)
    {
        return Validator::make($booking_management->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
